==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/CheckboxListDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CheckedChangedEventArgsDescriptionMetadata } from "./CheckedChangedEventArgsDescriptionMetadata";
import { SelectAllCheckboxChangedEventArgsDescriptionMetadata } from "./SelectAllCheckboxChangedEventArgsDescriptionMetadata";
import { CheckboxListDescription } from "./CheckboxListDescription";
/**
 * @hidden
 */
var CheckboxListDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(CheckboxListDescriptionMetadata, _super);
    function CheckboxListDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    CheckboxListDescriptionMetadata.b = function (a) {
        if (CheckboxListDescriptionMetadata.a == null) {
            CheckboxListDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            CheckboxListDescriptionMetadata.c(CheckboxListDescriptionMetadata.a);
        }
        if (a.j(CheckboxListDescriptionMetadata.a)) {
            return;
        }
        a.y(CheckboxListDescriptionMetadata.a);
        CheckedChangedEventArgsDescriptionMetadata.d(a);
        SelectAllCheckboxChangedEventArgsDescriptionMetadata.d(a);
    };
    CheckboxListDescriptionMetadata.c = function (a) {
        a.item("Keys", "Collection:PrimaryKeyValue:GridSelectedKeysCollection:PrimaryKeyValue");
        a.item("PrimaryKey", "Array:string");
        a.item("DataSourceRef", "(w:ItemsSource,xam:ItemsSource,wf:ItemsSource)DataRef::object");
        a.item("DataMemberPath", "String");
        a.item("SelectedMemberPath", "String");
        a.item("FilterPlaceholderText", "String");
        a.item("SearchInputType", "ExportedType:string:InputGroupDisplayType");
        a.item("SearchInputType@names", "Line;Box;Border;Search");
        a.item("RowHeight", "Number:int");
        a.item("CellFontFamily", "(w:CellFontFamily/FontFamilyTransform,xam:CellFontFamily,wf:CellFontFamily,web:cellTextStyle/FontFamilyTransform)String");
        a.item("CellFontSize", "(w:CellFontSize,xam:CellFontSize,wf:CellFontSize,web:cellTextStyle/FontSizeTransform)Number:double");
        a.item("CellFontStyle", "(w:CellFontStyle/FontStyleTransform,xam:CellFontFamily/FontStyleTransform,wf:CellFontFamily/FontStyleTransform,web:cellTextStyle/FontStyleTransform)String");
        a.item("CellFontWeight", "(w:CellFontWeight/FontWeightTransform,xam:CellFontFamily/FontWeightTransform,wf:CellFontFamily/FontWeightTransform,web:cellTextStyle/FontWeightTransform)String");
        a.item("IndexType", "ExportedType:string:CheckboxListIndexType");
        a.item("IndexType@names", "Selected;DeSelected");
        a.item("BaseTheme", "ExportedType:string:BaseControlTheme");
        a.item("BaseTheme@names", "Default;DenaliLight;MaterialLight");
        a.item("Density", "ExportedType:string:ControlDisplayDensity");
        a.item("Density@names", "Auto;Comfortable;Cosy;Compact");
        a.item("ScrollbarStyle", "ExportedType:string:ScrollbarStyle");
        a.item("ScrollbarStyle@names", "Default;Fading;Thin");
        a.item("ScrollbarBackground", "Brush");
        a.item("SelectAllCaption", "String");
        a.item("SelectAllCaptionTextColor", "Brush");
        a.item("ActualSelectAllCaptionTextColor", "Brush");
        a.item("ShowSelectAll", "Boolean");
        a.item("BackgroundColor", "Brush");
        a.item("TextColor", "Brush");
        a.item("ShowFilter", "Boolean");
        a.item("IsRowHoverEnabled", "Boolean");
        a.item("CheckedChangedRef", "EventRef::checkedChanged");
        a.item("SelectAllCheckboxChangedRef", "EventRef::selectAllCheckboxChanged");
    };
    CheckboxListDescriptionMetadata.d = function (a) {
        CheckboxListDescriptionMetadata.b(a);
        a.aa("CheckboxList", function () { return new CheckboxListDescription(); });
        a.z("CheckboxList", CheckboxListDescriptionMetadata.a);
    };
    CheckboxListDescriptionMetadata.$t = markType(CheckboxListDescriptionMetadata, 'CheckboxListDescriptionMetadata');
    CheckboxListDescriptionMetadata.a = null;
    return CheckboxListDescriptionMetadata;
}(Base));
export { CheckboxListDescriptionMetadata };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/CheckboxListDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CheckedChangedEventArgsDescriptionMetadata } from "./CheckedChangedEventArgsDescriptionMetadata";
import { SelectAllCheckboxChangedEventArgsDescriptionMetadata } from "./SelectAllCheckboxChangedEventArgsDescriptionMetadata";
import { CheckboxListDescription } from "./CheckboxListDescription";
/**
 * @hidden
 */
var CheckboxListDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(CheckboxListDescriptionMetadata, _super);
    function CheckboxListDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    CheckboxListDescriptionMetadata.b = function (a) {
        if (CheckboxListDescriptionMetadata.a == null) {
            CheckboxListDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            CheckboxListDescriptionMetadata.c(CheckboxListDescriptionMetadata.a);
        }
        if (a.k(CheckboxListDescriptionMetadata.a)) {
            return;
        }
        a.aa(CheckboxListDescriptionMetadata.a);
        CheckedChangedEventArgsDescriptionMetadata.d(a);
        SelectAllCheckboxChangedEventArgsDescriptionMetadata.d(a);
    };
    CheckboxListDescriptionMetadata.c = function (a) {
        a.item("Keys", "Collection:PrimaryKeyValue:GridSelectedKeysCollection:PrimaryKeyValue");
        a.item("PrimaryKey", "Array:string");
        a.item("DataSourceRef", "(w:ItemsSource,xam:ItemsSource,wf:ItemsSource)DataRef::object");
        a.item("DataMemberPath", "String");
        a.item("SelectedMemberPath", "String");
        a.item("FilterPlaceholderText", "String");
        a.item("SearchInputType", "ExportedType:string:InputGroupDisplayType");
        a.item("SearchInputType@names", "Line;Box;Border;Search");
        a.item("RowHeight", "Number:int");
        a.item("CellFontFamily", "(w:CellFontFamily/FontFamilyTransform,xam:CellFontFamily,wf:CellFontFamily,web:cellTextStyle/FontFamilyTransform)String");
        a.item("CellFontSize", "(w:CellFontSize,xam:CellFontSize,wf:CellFontSize,web:cellTextStyle/FontSizeTransform)Number:double");
        a.item("CellFontStyle", "(w:CellFontStyle/FontStyleTransform,xam:CellFontFamily/FontStyleTransform,wf:CellFontFamily/FontStyleTransform,web:cellTextStyle/FontStyleTransform)String");
        a.item("CellFontWeight", "(w:CellFontWeight/FontWeightTransform,xam:CellFontFamily/FontWeightTransform,wf:CellFontFamily/FontWeightTransform,web:cellTextStyle/FontWeightTransform)String");
        a.item("IndexType", "ExportedType:string:CheckboxListIndexType");
        a.item("IndexType@names", "Selected;DeSelected");
        a.item("BaseTheme", "ExportedType:string:BaseControlTheme");
        a.item("BaseTheme@names", "Default;DenaliLight;MaterialLight");
        a.item("Density", "ExportedType:string:ControlDisplayDensity");
        a.item("Density@names", "Auto;Comfortable;Cosy;Compact");
        a.item("ScrollbarStyle", "ExportedType:string:ScrollbarStyle");
        a.item("ScrollbarStyle@names", "Default;Fading;Thin");
        a.item("ScrollbarBackground", "Brush");
        a.item("SelectAllCaption", "String");
        a.item("SelectAllCaptionTextColor", "Brush");
        a.item("ActualSelectAllCaptionTextColor", "Brush");
        a.item("ShowSelectAll", "Boolean");
        a.item("BackgroundColor", "Brush");
        a.item("TextColor", "Brush");
        a.item("ShowFilter", "Boolean");
        a.item("IsRowHoverEnabled", "Boolean");
        a.item("CheckedChangedRef", "EventRef::checkedChanged");
        a.item("SelectAllCheckboxChangedRef", "EventRef::selectAllCheckboxChanged");
    };
    CheckboxListDescriptionMetadata.d = function (a) {
        CheckboxListDescriptionMetadata.b(a);
        a.ac("CheckboxList", function () { return new CheckboxListDescription(); });
        a.ab("CheckboxList", CheckboxListDescriptionMetadata.a);
    };
    CheckboxListDescriptionMetadata.$t = markType(CheckboxListDescriptionMetadata, 'CheckboxListDescriptionMetadata');
    CheckboxListDescriptionMetadata.a = null;
    return CheckboxListDescriptionMetadata;
}(Base));
export { CheckboxListDescriptionMetadata };
